import {
  IEventParam,
  Metadata,
  Http,
  Loader,
  Datasource,
} from '@zeedhi/core';
import {
  Select,
  GridEditable,
  Form,
  Switch,
  Button,
} from '@zeedhi/common';

export class ParametersDashboardController {
  private profileCurrentRow: any = {};
  
  public createModals() {
    const addProfile = Loader.getInstance('AddProfileAccessModalController');
    const filterModal = Loader.getInstance('FilterParamDashModalController');
    const exceptionProfile = Loader.getInstance('ExceptionProfileModalController');
    addProfile.createProfileModal();
    filterModal.createFilterParamDashModal();
    exceptionProfile.createExceptionProfile();
  }
  
  public isNotEditingGrid = true;

  get disabledButtons() {
    return !this.isNotEditingGrid;
  }
  
  public onInlineEditGrid(component) {
    this.isNotEditingGrid = !component.editing;
  }
  
  public checkGridEdit = true;
  
  public editingModeGrid({ component }: IEventParam<GridEditable>) {
    this.checkGridEdit = !component.editing;
    this.onInlineEditGrid(component);
  }
  
  public checkGridEditIndicator = true;
  
  public editingModeIndicator({ component }: IEventParam<GridEditable>) {
    this.checkGridEditIndicator = !component.editing;
  }
  
  get hasNoProfile() {
    return !this.profileCurrentRow.NRPERFACLPAINEL;
  }

  get hasProfile() {
    return !!this.profileCurrentRow.NRPERFACLPAINEL;
  }

  public changeProfile({ component }: IEventParam<Datasource>) {
    this.profileCurrentRow = component.currentRow;
  }
  
  get disabledButton(): boolean {
    const grid = Metadata.getInstance<GridEditable>('parametersEditGrid');
    return grid.selectedRows.length <= 0;
  }
  
  public deleteProfile({ component }: any) {
    const grid = Metadata.getInstance<GridEditable>('parametersEditGrid');
    const rows = component.parent;
    Http.post('/dellProfileAccess', {
      requestType: 'DataSet',
      dataset: rows.selectedRows,
    }).then(() => {
      grid.datasource.get();
      rows.selectedRows = [];
    });
  }
  
  public saveProfileAccess() {
    const formProfile = Metadata.getInstance<Form>('FormAddProfile');
    const perfil = formProfile.getChildInstance<Select>('PERFIL');
    const initialPanel = formProfile.getChildInstance<Switch>('IDPADRAODASH');
    const gridProfile = Metadata.getInstance<GridEditable>('parametersEditGrid');
    if (perfil.value) {
      const conditions = {
        NRPERFILACESSO: perfil.value,
        IDPADRAODASH: initialPanel.value,
        CDFILIAL: perfil.datasource.filter.CDFILIAL,
        NRPAINEL: perfil.datasource.filter.NRPAINEL,
      };
        
      Http.post('/addProfileAccess', {
        requestType: 'Row',
        row: conditions,
      }).then(() => {
        gridProfile.datasource.get();
        const controllerProfile = Loader.getInstance('AddProfileAccessModalController');
        controllerProfile.closeModalProfile();
      });
    } else {
      formProfile.validate();
    }
  }
  
  public profileGridClick({ row }: IEventParam<GridEditable>) {
    const indicator = Metadata.getInstance<GridEditable>('indicatorGrid');
    const conditions = {
      NRPERFACLPAINEL: row.NRPERFACLPAINEL,
      NRPAINEL: row.NRPAINEL,
    };
    indicator.datasource.setFilter(conditions);
  }
  
  public async cancelEditing() {
    const grid = Metadata.getInstance<GridEditable>('parametersEditGrid');
    await grid.cancelEditedRows();
    this.editingModeGrid({ component: grid });
  }
  
  public async saveEditingGrid({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    const data = grid.getEditedRows();
    Http.post('/rowsProfileUpdate', {
      requestType: 'DataSet',
      dataset: data,
    });
    await grid.cancelEditedRows();
    this.editingModeGrid({ component: grid });
  }
  
  public async saveIndicatorDisplayed({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    const numProfile = grid.datasource.filter.NRPERFACLPAINEL;
    const rowsEdited = grid.getEditedRows();
    const sendObject = {
      NRPERFACLPAINEL: numProfile,
      INDICATOR: rowsEdited,
    };
    Http.post('/rowsUpdateIndicator', {
      requestType: 'Row',
      row: sendObject,
    });
    grid.datasource.get();
    this.cancelDisplayedIndicator();
    this.editingModeGrid({ component: grid });
  }
  
  public async cancelDisplayedIndicator() {
    const grid = Metadata.getInstance<GridEditable>('indicatorGrid');
    await grid.cancelEditedRows();
    this.editingModeIndicator({ component: grid });
  }
}
